==> haskell-wai-middleware-static-0.9.2-247-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-middleware-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-middleware-static
version:              0.9.2
visibility:           public
id:                   wai-middleware-static-0.9.2-xJ7s3ZDMzH3N4gdexT5i
key:                  wai-middleware-static-0.9.2-xJ7s3ZDMzH3N4gdexT5i
license:              BSD-3-Clause
copyright:            (c) 2012-2014 Andrew Farmer
maintainer:           Andrew Farmer <afarmer@ittc.ku.edu>
author:               Andrew Farmer <afarmer@ittc.ku.edu>
stability:            experimental
homepage:             https://github.com/scotty-web/wai-middleware-static
synopsis:             WAI middleware that serves requests to static files.
description:
    WAI middleware that intercepts requests to static files and serves them
    if they exist.

    [WAI] <http://hackage.haskell.org/package/wai>

category:             Web
abi:                  61f6d5b92f4804db32fc364cd8479ed3
exposed:              True
exposed-modules:      Network.Wai.Middleware.Static
import-dirs:          /usr/lib/ghc-9.2.8/site-local/wai-middleware-static-0.9.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/wai-middleware-static-0.9.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-middleware-static
hs-libraries:         HSwai-middleware-static-0.9.2-xJ7s3ZDMzH3N4gdexT5i
depends:
    base-4.16.4.0 base16-bytestring-1.0.2.0-KWjk12Kc0JO2Mp5RJvDvOx
    bytestring-0.11.4.0 containers-0.6.5.1
    cryptohash-sha1-0.11.101.0-HzrEYanEvCZBYZYFg1QugH directory-1.3.6.2
    expiring-cache-map-0.0.6.1-ELE906ogHkBH6TYCcH5L6x filepath-1.4.2.2
    http-types-0.12.4-B3znMwHTe3dL304Bd3IJgZ
    mime-types-0.1.2.0-4X5b6Sz1aAM6TugVqfWYtQ
    old-locale-1.0.0.7-DSFeUNZwxUU2YUIlh1bsq7 text-1.2.5.0
    time-1.11.1.1 wai-3.2.4-JJVI15W7E9rGAtOPSLOeBU

haddock-interfaces:
    /usr/share/doc/haskell-wai-middleware-static/html/wai-middleware-static.haddock

haddock-html:         /usr/share/doc/haskell-wai-middleware-static/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-middleware-static-0.9.2-274-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-middleware-static.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-middleware-static
version:              0.9.2
visibility:           public
id:                   wai-middleware-static-0.9.2-3QQ1FJOEN0vEoz38zb7EnZ
key:                  wai-middleware-static-0.9.2-3QQ1FJOEN0vEoz38zb7EnZ
license:              BSD-3-Clause
copyright:            (c) 2012-2014 Andrew Farmer
maintainer:           Andrew Farmer <afarmer@ittc.ku.edu>
author:               Andrew Farmer <afarmer@ittc.ku.edu>
stability:            experimental
homepage:             https://github.com/scotty-web/wai-middleware-static
synopsis:             WAI middleware that serves requests to static files.
description:
    WAI middleware that intercepts requests to static files and serves them
    if they exist.

    [WAI] <http://hackage.haskell.org/package/wai>

category:             Web
abi:                  b0af84f2aaa6baa16c7c384026b403bd
exposed:              True
exposed-modules:      Network.Wai.Middleware.Static
import-dirs:          /usr/lib/ghc-9.2.8/site-local/wai-middleware-static-0.9.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/wai-middleware-static-0.9.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-middleware-static
hs-libraries:         HSwai-middleware-static-0.9.2-3QQ1FJOEN0vEoz38zb7EnZ
depends:
    base-4.16.4.0 base16-bytestring-1.0.2.0-1EKQKfIbtqrKykCu8OdSyV
    bytestring-0.11.4.0 containers-0.6.5.1
    cryptohash-sha1-0.11.101.0-9MEu4tFaPJgGxWAmjIEvHn directory-1.3.6.2
    expiring-cache-map-0.0.6.1-FIfhC5yG1rb3zKLFoqwzZE filepath-1.4.2.2
    http-types-0.12.4-4jA7skhyc4O1mTcupRz8pv
    mime-types-0.1.2.0-4X5b6Sz1aAM6TugVqfWYtQ
    old-locale-1.0.0.7-DSFeUNZwxUU2YUIlh1bsq7 text-1.2.5.0
    time-1.11.1.1 wai-3.2.4-JIqkXCnMPAzFKNQzPpgW2q

haddock-interfaces:
    /usr/share/doc/haskell-wai-middleware-static/html/wai-middleware-static.haddock

haddock-html:         /usr/share/doc/haskell-wai-middleware-static/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
